summaryrefslogtreecommitdiff
path: root/Lib/uuid.py
diff options
context:
space:
mode:
authorR David Murray <rdmurray@bitdance.com>2013-12-17 21:13:16 -0500
committerR David Murray <rdmurray@bitdance.com>2013-12-17 21:13:16 -0500
commit4be1e24933db192b3cf95e102a46673bb3312dc3 (patch)
treefa5fffe594ed4c7ab826c9294f900645e21931cc /Lib/uuid.py
parent320b39158ebfd63f25eb5f10dd65792334445eda (diff)
downloadcpython-git-4be1e24933db192b3cf95e102a46673bb3312dc3.tar.gz
#19855: uuid.get_node now looks on the PATH for executables on unix.
Patch by Serhiy Storchaka.
Diffstat (limited to 'Lib/uuid.py')
-rw-r--r--Lib/uuid.py55
1 files changed, 28 insertions, 27 deletions
diff --git a/Lib/uuid.py b/Lib/uuid.py
index d5c3160fdf..7705a8ad40 100644
--- a/Lib/uuid.py
+++ b/Lib/uuid.py
@@ -312,34 +312,35 @@ class UUID(object):
return int((self.int >> 76) & 0xf)
def _find_mac(command, args, hw_identifiers, get_index):
- import os
- for dir in ['', '/sbin/', '/usr/sbin']:
- executable = os.path.join(dir, command)
- if not os.path.exists(executable):
- continue
+ import os, shutil
+ executable = shutil.which(command)
+ if executable is None:
+ path = os.pathsep.join(('/sbin', '/usr/sbin'))
+ executable = shutil.which(command, path=path)
+ if executable is None:
+ return None
- try:
- # LC_ALL to get English output, 2>/dev/null to
- # prevent output on stderr
- cmd = 'LC_ALL=C %s %s 2>/dev/null' % (executable, args)
- with os.popen(cmd) as pipe:
- for line in pipe:
- words = line.lower().split()
- for i in range(len(words)):
- if words[i] in hw_identifiers:
- try:
- return int(
- words[get_index(i)].replace(':', ''), 16)
- except (ValueError, IndexError):
- # Virtual interfaces, such as those provided by
- # VPNs, do not have a colon-delimited MAC address
- # as expected, but a 16-byte HWAddr separated by
- # dashes. These should be ignored in favor of a
- # real MAC address
- pass
- except IOError:
- continue
- return None
+ try:
+ # LC_MESSAGES to get English output, 2>/dev/null to
+ # prevent output on stderr
+ cmd = 'LC_MESSAGES=C %s %s 2>/dev/null' % (executable, args)
+ with os.popen(cmd) as pipe:
+ for line in pipe:
+ words = line.lower().split()
+ for i in range(len(words)):
+ if words[i] in hw_identifiers:
+ try:
+ return int(
+ words[get_index(i)].replace(':', ''), 16)
+ except (ValueError, IndexError):
+ # Virtual interfaces, such as those provided by
+ # VPNs, do not have a colon-delimited MAC address
+ # as expected, but a 16-byte HWAddr separated by
+ # dashes. These should be ignored in favor of a
+ # real MAC address
+ pass
+ except IOError:
+ pass
def _ifconfig_getnode():
"""Get the hardware address on Unix by running ifconfig."""